@@ -1,7 +1,9 @@
+use reqwest::Url;
 use serde::Deserialize;
 use async_trait::async_trait;
 use crate::segment::Segment;
 use crate::get::Get;
+use crate::error::VimeoError;
 
 #[derive(Debug, Deserialize)]
 pub struct Audio {
@@ -10,12 +12,6 @@ pub struct Audio {
     segments: Vec<Segment>
 }
 
-impl Audio {
-    pub fn base_url(&self) -> &str {
-        &self.base_url
-    }
-}
-
 #[async_trait]
 impl Get for Audio {
     fn init_segment(&self) -> &str {
@@ -25,4 +21,11 @@ impl Get for Audio {
     fn segments(&self) -> &[Segment] {
         &self.segments
     }
+
+    fn url(&self, base_url: &Url) -> Result<Url, VimeoError> {
+        let (_, url) = self.base_url.split_at(3);
+        let url = base_url.join(url)?;
+
+        Ok(url)
+    }
 }
\ No newline at end of file
