@@ -7,7 +7,10 @@ mod segment;
 mod get;
 
 pub use error::VimeoError;
-pub use get::get_movie;
+pub use get::{get_audio, get_video, get_movie};
 
 #[cfg(feature = "progressbar")]
-pub use indicatif::{ProgressBar, ProgressStyle, MultiProgress};
\ No newline at end of file
+pub use indicatif::{ProgressBar, ProgressStyle, MultiProgress};
+
+#[cfg(feature = "progressbar")]
+pub use get::{get_audio_with, get_video_with, get_movie_with};
\ No newline at end of file
